==> tine20-allinone_2020.08.8.tar.bz2: Admin/js/Admin-lang-ca-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nLanguage: ca\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: "Paràmetres {0}"

, "Search:"
: "Cerca:"

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Es mostren les aplicacions {0} - {1} de {2}"

, "No applications to display"
: "Cap aplicació a mostrar"

, "Order"
: "Ordre"

, "Name"
: "Nom"

, "Status"
: "Estat"

, "Version"
: "Versió"

, "Confirm"
: "Confirma"

, "Do you really want to delete the selected groups?"
: "Esteu segur que voleu eliminar els grups seleccionats?"

, "Deleting group(s)..."
: "Eliminant grup(s)..."

, "Failed"
: "Ha fallat"

, "Some error occurred while trying to delete the group."
: "S'ha produït un error quan s'intentava eliminar el grup."

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "Es mostren els grups {0} - {1} de {2}"

, "No groups to display"
: "Cap grup a mostrar"

, "ID"
: "Identificador"

, "E-mail"
: ""

, "Description"
: "Descripció"

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: "Errors"

, "Please configure store for this field type"
: ""

, "Application, Applications"
: [
  ""
 ,""

]
, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: "Cancel·la"

, "OK"
: ""

, "Configure store"
: ""

, "Model"
: ""

, "Custom field definition"
: ""

, "Text"
: ""

, "Textarea"
: ""

, "Number"
: ""

, "Date"
: ""

, "DateTime"
: ""

, "Time"
: ""

, "Boolean"
: ""

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Type"
: ""

, "Label"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Group, Groups"
: [
  ""
 ,""

]
, "Customfield already exists. Please choose another name."
: ""

, "Customfield, Customfields"
: [
  ""
 ,""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""
 ,""

]
, "Value"
: ""

, "Default ({0})"
: ""

, "Computer Name"
: "Nom de l'ordinador"

, "Default Addressbook for new contacts and groups"
: ""

, "Please wait"
: "Espereu"

, "Updating Tag"
: "Actualitzant etiqueta"

, "Could not save tag ({0})"
: ""

, "Please fix the errors noted."
: "Solventeu els errors citats."

, "Allowed Contexts"
: "Contextos permesos"

, "Context"
: "Context"

, "Account Rights"
: "Permisos del compte"

, "View"
: "Visualitza"

, "Use"
: "Utilitza"

, "Tag Name"
: "Nom d'etiqueta"

, "Color"
: "Color"

, "Transferring {0}..."
: ""

, "Tag"
: "Etiqueta"

, "Add New Tag"
: "Afegeix una nova etiqueta"

, "Edit Tag \"{0}\""
: "Edita l'etiqueta \"{0}\""

, "Do you really want to delete the selected tags?"
: "Esteu segur que voleu eliminar les etiquetes seleccionades?"

, "Deleting tag(s)..."
: "Eliminant etiqueta(es)..."

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: "Es mostren les etiquetes {0} - {1} de {2}"

, "No tags to display"
: "Cap etiqueta a mostrar"

, "Usage:&#160;"
: ""

, "Updating Memberships"
: "S'actualitzen les pertanyences com a membres"

, "Could not save role."
: "No s'ha pogut desar el rol."

, "Deleting role..."
: "Eliminant el rol..."

, "Some error occurred while trying to delete the role."
: "S'ha produït un error quan s'intentava eliminar el rol."

, "Rights"
: "Permisos"

, "Members"
: "Membres"

, "Role Name"
: "Nom del rol"

, "Role"
: "Rol"

, "Add New Role"
: "Afegeix un nou rol"

, "Edit Role \"{0}\""
: "Edita el rol \"{0}\""

, "Do you really want to delete the selected roles?"
: "Esteu segur que voleu eliminar els rols seleccionats?"

, "Deleting role(s)..."
: "Eliminant el(s) rol(s)..."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: "Es mostren els rols {0} - {1} de {2}"

, "No roles to display"
: "Cap rol a mostrar"

, "Access Log, Access Logs"
: [
  ""
 ,""

]
, "Groups"
: "Grups"

, "Applications"
: "Aplicacions"

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Les contrasenyes no coincideixen!"

, "Passwords match!"
: ""

, "Primary group"
: "Grup primari"

, "Unix"
: "Unix"

, "Home Directory"
: "Directori \"home\""

, "Login Shell"
: "intèrpret d'ordres"

, "Windows"
: "Windows"

, "Home Drive"
: "Unitat \"home\""

, "Login Time"
: "Hora de l'inici de sessió"

, "never logged in"
: "no ha iniciat sessió mai"

, "Home Path"
: "Camí \"home\""

, "Logout Time"
: "Hora de la finalització de sessió"

, "never logged off"
: "no ha finalitzat la sessió mai"

, "Profile Path"
: "Camí del perfil"

, "Password Last Set"
: "Contrasenya establerta per darrera vegada"

, "never"
: "mai"

, "Logon Script"
: "Script d'inici de sessió"

, "Password Can Change"
: "La contrasenya pot canviar"

, "not set"
: "no establerta"

, "Password Must Change"
: "La contrasenya s'ha de canviar"

, "Kick Off Time"
: "Hora d'expulsió"

, "Filesystem Quota"
: ""

, "Quota"
: "Quota"

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: "Informació"

, "Last Login"
: "Darrer inici de sessió"

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: "Afegeix una adreça àlies..."

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: "Reenvia només"

, "Password confirmation"
: "Confirmació de contrasenya"

, "Repeat password"
: "Repetiu la contrasenya"

, "Ok"
: "D'acord"

, "Account"
: "Compte"

, "First name"
: "Nom"

, "Last name"
: "Cognom"

, "Login name"
: ""

, "Password"
: "Contrasenya"

, "OpenID"
: "OpenID"

, "enabled"
: "habilitat"

, "disabled"
: "inhabilitat"

, "expired"
: "caducat"

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "Expires"
: "Caduca"

, "Visibility"
: "Visibilitat"

, "Display in addressbook"
: "Mostra a la llibreta d'adreces"

, "Hide from addressbook"
: "Amaga a la llibreta d'adreces"

, "Saved in Addressbook"
: ""

, "Last login at"
: "Darrer inici de sessió a"

, "don't know"
: "no se sap"

, "Last login from"
: "Darrer inici de sessió des de"

, "Password set"
: "S'ha establert contrasenya"

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: "Servidor de fitxers"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "User, Users"
: [
  "Usuari"
 ,"Usuaris"

]
, "Users"
: ""

, "Samba User, Samba Users"
: [
  "Usuari de samba"
 ,"Usuaris de samba"

]
, "Email User, Email Users"
: [
  "Usuari de correu electrònic"
 ,"Usuaris de correu electrònic"

]
, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: "S'ha canviat la contrasenya"

, "Set new password"
: "Estableix una nova contrasenya"

, "Please enter the new password:"
: "Introduïu la nova contrasenya:"

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: "Nom del grup"

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Membres de grup"

, "personal"
: ""

, "shared"
: ""

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  ""
 ,""

]
, "Container Name"
: ""

, "Container Order"
: ""

, "Computer, Computers"
: [
  "Ordinador"
 ,"Ordinadors"

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: "Rols"

, "Containers"
: ""

, "Shared Tags"
: "Etiquetes compartides"

, "Customfields"
: ""

, "Computers"
: "Ordinadors"

, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Admin"
: "Administració"

, "Refresh"
: ""

, "Feature is disabled by configuration."
: ""

, "IP Address"
: "Adreça IP"

, "Client Type"
: ""

, "Session ID"
: "Identificador de sessió"

, "Login Name"
: "Nom d'usuari d'inici de sessió"

, "Result"
: "Resultat"

, "user blocked"
: ""

, "password expired"
: ""

, "user disabled"
: ""

, "invalid password"
: "contrasenya incorrecta"

, "ambiguous username"
: "nom d'usuari ambigu"

, "user not found"
: "no s'ha trobat l'usuari"

, "failure"
: "errada"

, "success"
: "èxit"

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""




































, "Application"
: ""

, "Group"
: ""

, "Customfield"
: ""

, "Config"
: ""

, "Access Log"
: ""

, "User"
: "Usuari"

, "Samba User"
: "Usuari de samba"

, "Email User"
: "Usuari de correu electrònic"

, "Container"
: ""

, "Computer"
: "Ordinador"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Admin/js/Admin-lang-ca-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nLanguage: ca\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "ImportExportDefinition, ImportExportDefinitions"
: [
  ""
 ,""

]
, "Application, Applications"
: [
  ""
 ,""

]
, "User, Users"
: [
  "Usuari"
 ,"Usuaris"

]
, "Groups"
: "Grups"

, "Roles"
: "Rols"

, "Applications"
: "Aplicacions"

, "Containers"
: ""

, "Shared Tags"
: "Etiquetes compartides"

, "Customfields"
: ""

, "Computers"
: "Ordinadors"

, "Access Log, Access Logs"
: [
  ""
 ,""

]
, "Log"
: ""

, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Import Export Definitions"
: ""

, "Admin"
: "Administració"

, "Refresh"
: ""

, "Disabled"
: ""

, "Feature is disabled by configuration."
: ""

, "Default Addressbook for new contacts and groups"
: ""

, "Computer Name"
: "Nom de l'ordinador"

, "Config, Configs"
: [
  ""
 ,""

]
, "Description"
: "Descripció"

, "Name"
: "Nom"

, "Label"
: ""

, "Value"
: ""

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Group Name"
: "Nom del grup"

, "Visibility"
: "Visibilitat"

, "Display in addressbook"
: "Mostra a la llibreta d'adreces"

, "Hide from addressbook"
: "Amaga a la llibreta d'adreces"

, "Saved in Addressbook"
: ""

, "E-mail"
: ""

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Membres de grup"

, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Confirm"
: "Confirma"

, "Do you really want to delete the selected tags?"
: "Esteu segur que voleu eliminar les etiquetes seleccionades?"

, "Deleting tag(s)..."
: "Eliminant etiqueta(es)..."

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Search:"
: "Cerca:"

, "Displaying tags {0} - {1} of {2}"
: "Es mostren les etiquetes {0} - {1} de {2}"

, "No tags to display"
: "Cap etiqueta a mostrar"

, "ID"
: "Identificador"

, "Color"
: "Color"

, "Usage:&#160;"
: ""

, "Do you really want to delete the selected roles?"
: "Esteu segur que voleu eliminar els rols seleccionats?"

, "Deleting role(s)..."
: "Eliminant el(s) rol(s)..."

, "Failed"
: "Ha fallat"

, "Some error occurred while trying to delete the role."
: "S'ha produït un error quan s'intentava eliminar el rol."

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: "Es mostren els rols {0} - {1} de {2}"

, "No roles to display"
: "Cap rol a mostrar"

, "Container Name"
: ""

, "Type"
: ""

, "Container Order"
: ""

, "Container, Containers"
: [
  ""
 ,""

]
, "Model"
: ""

, "personal"
: ""

, "shared"
: ""

, "Order"
: "Ordre"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Do you really want to delete the selected groups?"
: "Esteu segur que voleu eliminar els grups seleccionats?"

, "Deleting group(s)..."
: "Eliminant grup(s)..."

, "Some error occurred while trying to delete the group."
: "S'ha produït un error quan s'intentava eliminar el grup."

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: "Es mostren els grups {0} - {1} de {2}"

, "No groups to display"
: "Cap grup a mostrar"

, "Account only"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "IP Address"
: "Adreça IP"

, "Login Time"
: "Hora de l'inici de sessió"

, "Logout Time"
: "Hora de la finalització de sessió"

, "Client Type"
: ""

, "Session ID"
: "Identificador de sessió"

, "Login Name"
: "Nom d'usuari d'inici de sessió"

, "Result"
: "Resultat"

, "User Agent"
: ""

, "user blocked"
: ""

, "password expired"
: ""

, "user disabled"
: ""

, "invalid password"
: "contrasenya incorrecta"

, "ambiguous username"
: "nom d'usuari ambigu"

, "user not found"
: "no s'ha trobat l'usuari"

, "failure"
: "errada"

, "success"
: "èxit"

, "Customfield, Customfields"
: [
  ""
 ,""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Errors"
: "Errors"

, "Please configure store for this field type"
: ""

, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: "Cancel·la"

, "OK"
: ""

, "Configure store"
: ""

, "Custom field definition"
: ""

, "Text"
: ""

, "Textarea"
: ""

, "Number"
: ""

, "Date"
: ""

, "DateTime"
: ""

, "Time"
: ""

, "Boolean"
: ""

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Group, Groups"
: [
  ""
 ,""

]
, "Key"
: ""

, "Customfield already exists. Please choose another name."
: ""

, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Status"
: "Estat"

, "Display name"
: ""

, "Login name"
: ""

, "Last name"
: "Cognom"

, "First name"
: "Nom"

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: "OpenID"

, "Last login at"
: "Darrer inici de sessió a"

, "Last login from"
: "Darrer inici de sessió des de"

, "Password Must Change"
: "La contrasenya s'ha de canviar"

, "Password changed"
: "S'ha canviat la contrasenya"

, "Expires"
: "Caduca"

, "Set new password"
: "Estableix una nova contrasenya"

, "Please enter the new password:"
: "Introduïu la nova contrasenya:"

, "Users"
: ""

, "Samba User, Samba Users"
: [
  "Usuari de samba"
 ,"Usuaris de samba"

]
, "Email User, Email Users"
: [
  "Usuari de correu electrònic"
 ,"Usuaris de correu electrònic"

]
, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Les contrasenyes no coincideixen!"

, "Passwords match!"
: ""

, "Primary group"
: "Grup primari"

, "Unix"
: "Unix"

, "Home Directory"
: "Directori \"home\""

, "Login Shell"
: "intèrpret d'ordres"

, "Windows"
: "Windows"

, "Home Drive"
: "Unitat \"home\""

, "never logged in"
: "no ha iniciat sessió mai"

, "Home Path"
: "Camí \"home\""

, "never logged off"
: "no ha finalitzat la sessió mai"

, "Profile Path"
: "Camí del perfil"

, "Password Last Set"
: "Contrasenya establerta per darrera vegada"

, "never"
: "mai"

, "Logon Script"
: "Script d'inici de sessió"

, "Password Can Change"
: "La contrasenya pot canviar"

, "not set"
: "no establerta"

, "Kick Off Time"
: "Hora d'expulsió"

, "Filesystem Quota"
: ""

, "Quota"
: "Quota"

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: "Informació"

, "Last Login"
: "Darrer inici de sessió"

, "Forward Only"
: "Reenvia només"

, "E-mail Alias"
: ""

, "Add an alias address..."
: "Afegeix una adreça àlies..."

, "This alias can be used for sending e-mails."
: ""

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Password confirmation"
: "Confirmació de contrasenya"

, "Repeat password"
: "Repetiu la contrasenya"

, "Ok"
: "D'acord"

, "Account"
: "Compte"

, "Password"
: "Contrasenya"

, "Multi Factor Authentication Config"
: ""

, "enabled"
: "habilitat"

, "disabled"
: "inhabilitat"

, "expired"
: "caducat"

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "don't know"
: "no se sap"

, "Password set"
: "S'ha establert contrasenya"

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: "Servidor de fitxers"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Computer, Computers"
: [
  "Ordinador"
 ,"Ordinadors"

]
, "Please wait"
: "Espereu"

, "Updating Memberships"
: "S'actualitzen les pertanyences com a membres"

, "Could not save role."
: "No s'ha pogut desar el rol."

, "Please fix the errors noted."
: "Solventeu els errors citats."

, "Deleting role..."
: "Eliminant el rol..."

, "Rights"
: "Permisos"

, "Members"
: "Membres"

, "Role Name"
: "Nom del rol"

, "Transferring {0}..."
: ""

, "Role"
: "Rol"

, "Add New Role"
: "Afegeix un nou rol"

, "Edit Role \"{0}\""
: "Edita el rol \"{0}\""

, "Configs"
: ""

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Updating Tag"
: "Actualitzant etiqueta"

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: "Contextos permesos"

, "Context"
: "Context"

, "Account Rights"
: "Permisos del compte"

, "View"
: "Visualitza"

, "Use"
: "Utilitza"

, "Tag Name"
: "Nom d'etiqueta"

, "Tag"
: "Etiqueta"

, "Add New Tag"
: "Afegeix una nova etiqueta"

, "Edit Tag \"{0}\""
: "Edita l'etiqueta \"{0}\""

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: "Paràmetres {0}"

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Es mostren les aplicacions {0} - {1} de {2}"

, "No applications to display"
: "Cap aplicació a mostrar"

, "Version"
: "Versió"

, "Default password must change for new user settings"
: ""

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Password is needed for system account creation"
: ""

, "Notifications"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "Manage import and export definitions"
: ""

, "Add and edit import and export definitions"
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""

, "view ImportExportDefinitions"
: ""

































, "ImportExportDefinition"
: ""

, "Application"
: ""

, "User"
: "Usuari"

, "Access Log"
: ""

, "Config"
: ""

, "Container"
: ""

, "Customfield"
: ""

, "Group"
: ""

, "Samba User"
: "Usuari de samba"

, "Email User"
: "Usuari de correu electrònic"

, "Computer"
: "Ordinador"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
